@@ -633,6 +633,13 @@ class Commands(object):
             cmd = ['wget', '-r', '-nH', '--no-parent', '--reject', '"index.html*"', '-e', 'robots=off', '--no-verbose']
             cmd.extend(['-P', os.path.join(args.dest, chroot.name)])
             cmd.extend(['--cut-dirs', str(base_len + 4)])
+
+            if args.rpms:
+                cmd.extend(["-A", "*.rpm"])
+
+            if args.spec:
+                cmd.extend(["-A", "*.spec"])
+
             cmd.append(chroot.result_url)
             subprocess.call(cmd)
 
@@ -1104,9 +1111,10 @@ def setup_parser():
 
     parser_create.add_argument("--delete-after-days", default=None, metavar='DAYS',
                                help="Delete the project after the specfied period of time")
-    parser_create.add_argument("--module-hotfixes", choices=["on", "off"], default="off",
-                               help=("make packages from this project available "
-                                     "on along with packages from the active module streams."))
+    parser_create.add_argument(
+        "--module-hotfixes", choices=["on", "off"], default="off",
+        help=("Allow packages from this project to override packages from "
+              "active module streams."))
     parser_create.add_argument(
         "--multilib", choices=["on", "off"], default="off",
         help=("When users enable this copr repository on 64bit variant of "
@@ -1122,7 +1130,7 @@ def setup_parser():
               "the build itself."))
 
     parser_create.add_argument(
-        "--appstream", choices=["on", "off"], default="on",
+        "--appstream", choices=["on", "off"], default="off",
         help=("Generate AppStream metadata for this project. Generating "
               "metadata slows down the builds in large Copr projects."))
 
@@ -1162,9 +1170,10 @@ def setup_parser():
                                help=("Delete the project after the specfied "
                                      "period of time, empty or -1 disables, "
                                      "(default is \"don't change\")"))
-    parser_modify.add_argument("--module-hotfixes", choices=["on", "off"],
-                               help=("make packages from this project available "
-                                     "on along with packages from the active module streams."))
+    parser_modify.add_argument(
+        "--module-hotfixes", choices=["on", "off"],
+        help=("Allow packages from this project to override packages from "
+              "active module streams."))
     parser_modify.add_argument(
         "--multilib", choices=["on", "off"],
         help=("When users enable this copr repository on 64bit variant of "
@@ -1180,7 +1189,7 @@ def setup_parser():
               "the build itself."))
 
     parser_modify.add_argument(
-        "--appstream", choices=["on", "off"], default="on",
+        "--appstream", choices=["on", "off"], default="off",
         help=("Generate AppStream metadata for this project. Generating "
               "metadata slows down the builds in large Copr projects."))
 
@@ -1429,6 +1438,18 @@ def setup_parser():
                                        help="Select chroots to fetch")
     parser_download_build.add_argument("--dest", "-d", dest="dest",
                                        help="Base directory to store packages", default=".")
+    parser_download_build.add_argument(
+        "--rpms",
+        dest="rpms",
+        action="store_true",
+        help="Download only built RPM packages",
+    )
+    parser_download_build.add_argument(
+        "--spec",
+        dest="spec",
+        action="store_true",
+        help="Download only the .spec file",
+    )
     parser_download_build.set_defaults(func="action_download_build")
 
     # create the parser for the "cancel" command
